spool mcp <subcommand> command handlers.
Thin glue between the clap argument structs and the installers
module. Stays here (not inside installers/) to keep the installer
crate boundary independent from CLI argument types.
spool mcp <subcommand> command handlers.
Thin glue between the clap argument structs and the installers
module. Stays here (not inside installers/) to keep the installer
crate boundary independent from CLI argument types.