pub fn read_all(path: &Path) -> Result<Vec<TranscriptEntry>>Expand description
Parse the entire transcript at path into memory. Returns Ok with
the parsed prefix even when corrupt lines are encountered (those
are skipped and reported to stderr).
pub fn read_all(path: &Path) -> Result<Vec<TranscriptEntry>>Parse the entire transcript at path into memory. Returns Ok with
the parsed prefix even when corrupt lines are encountered (those
are skipped and reported to stderr).