pub fn load_entries(config_path: &Path) -> Result<Vec<LedgerEntry>>Expand description
Load entries from the lifecycle store for a given config path.
pub fn load_entries(config_path: &Path) -> Result<Vec<LedgerEntry>>Load entries from the lifecycle store for a given config path.